@@ -64,7 +64,7 @@ tools = [
 class Completions(object):
     def __init__(self, api_key: Optional[str] = None, base_url: Optional[str] = None):
         self.api_key = api_key
-        self.base_url = base_url or "https://g.chatfire.cn"
+        self.base_url = base_url or "https://all.chatfire.cc/genai"
         self.client = None  ####
 
     async def create_for_search(self, request: CompletionRequest):
