@@ -12,9 +12,8 @@ from meutils.pipe import *
 from meutils.db.redis_db import redis_aclient
 from meutils.apis.utils import make_request
 from meutils.schemas.hailuo_types import VideoRequest, VideoResponse, Video
-from meutils.config_utils.lark_utils import get_series, get_next_token_for_polling
-from meutils.llm.check_utils import check_token_for_ppinfra as check
-from meutils.notice.feishu import send_message_for_volc as send_message
+from meutils.config_utils.lark_utils import get_series, get_next_token_for_polling, get_next_token
+from meutils.llm.check_utils import check_token_for_ppinfra as check_token
 
 from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request, HTTPException, status, BackgroundTasks
 
@@ -22,24 +21,15 @@ base_url = "https://api.ppinfra.com/v3"
 feishu_url = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=b0e241"
 
 
-async def get_valid_token(tokens: Optional[list] = None):
-    tokens = tokens or await get_series(feishu_url)
-
-    for token in tokens:
-        if await check(token, threshold=1800):
-            logger.debug(f"有效 {token}")
-
-            return token
-        else:
-            logger.debug(f"无效 {token}")
-    _ = f"{time.ctime()}\n\n{feishu_url}\n\n所有token无效"
-    logger.error(_)
-    send_message(_, n=3)
+async def get_valid_token(min_points=18000):
+    _ = await get_next_token(feishu_url, check_token, min_points=min_points, ttl=600)
+    logger.debug(_)
+    return _
 
 
 # minimax-hailuo-02-6s-768p minimax-hailuo-02-6s-768p minimax-hailuo-02-6s-1080p
 async def create_task(request: VideoRequest, api_key: Optional[str] = None):
-    api_key = api_key or await get_valid_token()
+    api_key = api_key or await get_valid_token()  # 轮询
 
     payload = {
 
@@ -157,8 +147,8 @@ if __name__ == '__main__':
         duration=6,
         resolution="768P",
     )
-
-    # r = arun(create_task(request, api_key=api_key))
+    api_key = None
+    r = arun(create_task(request, api_key=api_key))
 
     # arun(get_task("d8b048d0-5c54-42ef-a691-3feab31693fe"))
 
