@@ -23,6 +23,7 @@ STEP = 2
 MINIMAX_VIDEO = 3
 
 FAL = 3
+FAL_ = 5
 FAL_MODELS = {
     'fal-kling-video-lipsync-audio-to-video': 0.5,
 
@@ -57,10 +58,44 @@ FAL_MODELS = {
     "fal-ai/minimax/voice-clone": 5,
 
     # vidu
-    "fal-ai/vidu/q1/text-to-video": 0.4 * FAL,
-    "fal-ai/vidu/q1/image-to-video": 0.4 * FAL,
-    "fal-ai/vidu/q1/start-end-to-video": 0.4 * FAL,
-    "fal-ai/vidu/q1/reference-to-video": 0.4 * FAL,
+    "fal-ai/vidu/q1/text-to-video": 0.4 * FAL_,
+    "fal-ai/vidu/q1/image-to-video": 0.4 * FAL_,
+    "fal-ai/vidu/q1/start-end-to-video": 0.4 * FAL_,
+    "fal-ai/vidu/q1/reference-to-video": 0.4 * FAL_,
+
+    "fal-ai/vidu/image-to-video": 0.2 * FAL_,
+    "fal-ai/vidu/start-end-to-video": 0.2 * FAL_,
+    "fal-ai/vidu/reference-to-video": 0.4 * FAL_,
+
+    # ideogram
+    "fal-ai/ideogram/v3/edit": 0.06 * FAL_,
+    "fal-ai/ideogram/v3/remix": 0.06 * FAL_,
+    "fal-ai/ideogram/v3/reframe": 0.06 * FAL_,
+    "fal-ai/ideogram/v3/replace-background": 0.06 * FAL_,
+
+    # recraft
+    "fal-ai/recraft/upscale/crisp": 0.004 * FAL_,
+    "fal-ai/recraft/upscale/creative": 0.25 * FAL_,
+    "fal-ai/recraft/v3/image-to-image": 0.006 * FAL_,  # 0.04 0.08 vec
+    "fal-ai/recraft/v3/text-to-image": 0.006 * FAL_,
+
+    # veo
+    "fal-ai/veo3/fast": 3.2 * FAL_,  # 2 3.2
+
+    # seedance
+    "fal-ai/bytedance/seedance/v1/lite/text-to-video": 1,
+    "fal-ai/bytedance/seedance/v1/lite/image-to-video": 1,
+    "fal-ai/bytedance/seedance/v1/pro/text-to-video": 3,
+    "fal-ai/bytedance/seedance/v1/pro/image-to-video": 3,
+
+    "fal-ai/bytedance/seededit/v3/edit-image": 0.1,
+    "fal-ai/bytedance/seedream/v3/text-to-image": 0.1,
+
+    # wan
+    "fal-ai/wan/v2.2-a14b/text-to-video": 0.08 * FAL_,
+    "fal-ai/wan/v2.2-a14b/image-to-video": 0.08 * FAL_,
+    "fal-ai/wan/v2.2-5b/text-to-video": 0.15 * FAL_,
+    "fal-ai/wan/v2.2-5b/image-to-video": 0.15 * FAL_,
 
 }
 
@@ -71,6 +106,11 @@ FAL_MODELS = {
 MODEL_PRICE = {
     **FAL_MODELS,
 
+    "qwen-image": 0.15,
+
+    "wan-ai-wan2.1-t2v-14b": 1,
+    "wan-ai-wan2.1-t2v-14b-turbo": 1,
+
     "async-task": 0.0001,
     "chatfire-claude": 0.02,
     "o1:free": FREE,
@@ -86,6 +126,7 @@ MODEL_PRICE = {
     "indextts-1.5": 0.02,
     "cosyvoice2": 0.02,
     "step-audio-tts-3b": 0.02,
+    "f5-tts": 0.02,
 
     # 谷歌
     "gemini-2.0-flash-search": 0.01,
@@ -191,10 +232,12 @@ MODEL_PRICE = {
 
     "tts-pro": 0.03,
 
-    # 官方api
+    # 官方apit todo 免费模型
     "cogvideox-flash": 0.05,
     "cogvideox": 0.1,
     "cogvideox-2": 0.2,
+    "cogvideox-3": 0.5,
+    "cogvideox-3-flash": 0.1,
 
     "official-api-cogvideox": 0.1,
     "official-api-kling-video": 0.5,
@@ -231,10 +274,13 @@ MODEL_PRICE = {
     "ideogram-ai/ideogram-v2": 0.2,
     "ideogram-ai/ideogram-v2-turbo": 0.1,
 
+    "imagen3": 0.05 * 3,
+    "imagen3-fast": 0.025 * 3,
     "imagen4": 0.05 * 3,
     "imagen4-fast": 0.02 * 3,
     "imagen4-ultra": 0.075 * 3,
 
+    "flux-kontext-dev": 0.04,
     "flux-kontext-pro": 0.04 * 3,
     "flux-kontext-max": 0.08 * 3,
 
@@ -486,12 +532,19 @@ MODEL_RATIO = {
     'fal-elevenlabs-tts-multilingual-v2': 3 * 0.1 * 1000 / 2,
 
     # fal 按量计费
+    "fal-ffmpeg-api-compose": 3 * 0.1 * 1000 / 2,
     "fal-topaz-upscale-video": 3 * 0.1 * 1000 / 2,
     "fal-luma-dream-machine-ray-2-reframe": 3 * 0.2 * 1000 / 2,
     "fal-luma-dream-machine-ray-2-flash-reframe": 3 * 0.06 * 1000 / 2,
 
-    "fal-minimax-speech-02-hd": 3 * 0.06 * 1000 / 2,
-    "fal-minimax-speech-02-turbo": 3 * 0.1 * 1000 / 2,
+    "fal-minimax-speech-02-hd": 3 * 0.1 * 1000 / 2,
+    "fal-minimax-speech-02-turbo": 3 * 0.06 * 1000 / 2,
+
+    "minimax-speech-02-hd": 125,
+    "minimax-speech-02-turbo": 75,
+
+    "fal-ai/minimax/speech-02-hd": 3 * 0.1 * 1000 / 2,
+    "fal-ai/minimax/speech-02-turbo": 3 * 0.06 * 1000 / 2,
 
     # 智能体
     "gpt-4-plus": 2.5,
@@ -516,9 +569,11 @@ MODEL_RATIO = {
     "bge-large-en-v1.5": 0.1,
     "BAAI/bge-large-en-v1.5": 0.1,
 
-    "text-embedding-3-large": 0.5,
-    "text-embedding-3-small": 0.5,
-    "text-embedding-ada-002": 0.5,
+    "text-embedding-3-large": 0.1,
+    "text-embedding-3-small": 0.1,
+    "text-embedding-ada-002": 0.1,
+    "jina-embeddings-v4": 0.1,
+    "jina-reranker-m0": 0.1,
 
     # 百川
     'baichuan4-turbo': 7.5,
@@ -593,6 +648,12 @@ MODEL_RATIO = {
     "glm-4.1v-thinking-flash": 0.1,
     "glm-4.1v-thinking-flashx": 1,
 
+    "glm-4.5-flash": 0.1,
+    "glm-4.5-air": 0.2,
+    "glm-4.5-airx": 1,
+    "glm-4.5": 0.5,
+    "glm-4.5-x": 2,
+
     # 阿里千问 https://dashscope.console.aliyun.com/billing
     "qwen-long": 0.25,
     "qwen-turbo": 0.05,
@@ -607,6 +668,7 @@ MODEL_RATIO = {
     "qwen-vl-max-latest": 1.5,
     "qwen-vl-plus-latest": 0.75,
 
+    "qwen2.5-vl-3b-instruct": 0.1,
     "qwen2.5-vl-7b-instruct": 0.15,
     "qwen2.5-vl-32b-instruct": 0.5,
     "qwen2.5-vl-72b-instruct": 1.5,
@@ -624,10 +686,17 @@ MODEL_RATIO = {
     "qwen3-4b": 0.2,
     "qwen3-8b": 0.25,
     "qwen3-14b": 0.5,
-    "qwen3-32b": 1,
+    "qwen3-32b": 2,
     "qwen3-30b-a3b": 0.75,
-    "qwen3-235b-a22b": 2,
+    "qwen3-30b-a3b-instruct-2507": 0.75,
+    "qwen3-235b-a22b": 1,
     "qwen-math-plus": 2,
+    "qwen3-coder-480b-a35b-instruct": 3,
+    "qwen3-235b-a22b-instruct-2507": 1,
+    "qwen3-235b-a22b-thinking-2507": 3,
+
+    "qwen3-coder-plus": 2,
+    "qwen3-coder-plus-2025-07-22": 2,
 
     "qwq-32b": 0.5,
     "qwq-plus": 0.8,
@@ -763,9 +832,12 @@ MODEL_RATIO = {
     "meta-deepresearch": 2,
 
     # 豆包
-    "doubao-seed-1-6-flash-250615": 0.075,
+    "seed-x-ppo-7b": 0.3,
+    "doubao-seed-1-6-flash-250715": 0.15,
+    "doubao-seed-1-6-flash-250615": 0.15,
     "doubao-seed-1-6-250615": 0.4,
     "doubao-seed-1-6-thinking-250615": 0.4,
+    "doubao-seed-1-6-thinking-250715": 0.4,
 
     "doubao-1-5-ui-tars-250428": 1.75,
     "ui-tars-72b": 1.75,
@@ -937,9 +1009,10 @@ MODEL_RATIO = {
     "gemini-2.0-flash-thinking-exp-1219": 0.075,
     "gemini-2.0-flash-thinking-exp-01-21": 0.075,
     "gemini-2.5-flash": 0.15,
+    "gemini-2.5-flash-preview-05-20": 0.075,
+    "gemini-2.5-flash-preview-05-20-nothinking": 0.075,
 
     "gemini-2.5-flash-preview-04-17": 0.075,
-    "gemini-2.5-flash-preview-05-20": 0.075,
 
     "gemini-2.0-pro": 0.625,
     "gemini-2.0-pro-exp": 0.625,
@@ -1036,8 +1109,8 @@ MODEL_RATIO = {
     "o3-pro-2025-06-10": 10,
 
     # 硅基
-    "llama-3.1-8b-instruct": 0.01,
-    "meta-llama/Meta-Llama-3.1-8B-Instruct": 0.01,
+    "llama-3.1-8b-instruct": 0.03,
+    "meta-llama/Meta-Llama-3.1-8B-Instruct": 0.03,
     "llama-3.1-70b-instruct": 2,
     "meta-llama/Meta-Llama-3.1-70B-Instruct": 2,
     "llama-3.1-405b-instruct": 5,
@@ -1049,6 +1122,7 @@ MODEL_RATIO = {
     "meta-llama/Llama-4-Scout-17B-16E-Instruct": 0.1,
     "meta-llama/Llama-4-Maverick-17B-128E-Instruct-FP8": 0.2,
     "meta-llama/Llama-4-Maverick-17B-128E-Instruct-Turbo": 0.2,
+    "llama-4-maverick": 0.5,
 
     # groq https://console.groq.com/docs/models
     "llama3-8b-8192": 0.01,
@@ -1204,6 +1278,10 @@ COMPLETION_RATIO = {
     "meta-llama/Llama-4-Scout-17B-16E-Instruct": 4,
     "meta-llama/Llama-4-Maverick-17B-128E-Instruct-FP8": 4,
     "meta-llama/Llama-4-Maverick-17B-128E-Instruct-Turbo": 4,
+    "llama-4-maverick": 4,
+
+    "llama-3.1-8b-instruct": 3,
+    "meta-llama/Meta-Llama-3.1-8B-Instruct": 3,
 
     "llama-3.3-70b-instruct": 4,
 
@@ -1275,9 +1353,11 @@ COMPLETION_RATIO = {
     "google/gemma-3-27b-it": 4,
     # thinking
     "gemini-2.5-flash-thinking": 23,
+
     "gemini-2.5-flash-preview-04-17-thinking": 23,
     "gemini-2.5-flash-preview-05-20-thinking": 23,
-
+    "gemini-2.5-flash-preview-05-20": 8.33333,
+    "gemini-2.5-flash-preview-05-20-nothinking": 8.33333,
     "gemini-2.5-pro-think": 4,
 
     "gemini-2.5-pro-thinking": 4,
@@ -1323,6 +1403,11 @@ COMPLETION_RATIO = {
     "qwen2.5-72b-instruct": 4,
     "qwen2.5-math-72b-instruct": 4,
 
+    "qwen2.5-7b-instruct-1m": 3,
+    "qwen2.5-14b-instruct-1m": 3,
+
+    "qwen2.5-vl-3b-instruct": 3,
+
     "qwen3-0.6b": 4,
     "qwen3-1.7b": 4,
     "qwen3-4b": 4,
@@ -1331,17 +1416,25 @@ COMPLETION_RATIO = {
     "qwen3-14b": 4,
     "qwen3-32b": 4,
     "qwen3-30b-a3b": 4,
-    "qwen3-235b-a22b": 3,
+    "qwen3-30b-a3b-instruct-2507": 4,
+    "qwen3-235b-a22b": 4,
     "qwenlong-l1-32b": 4,
+    "qwen3-235b-a22b-instruct-2507": 4,
+    "qwen3-235b-a22b-thinking-2507": 4,
+    "qwen3-coder-480b-a35b-instruct": 4,
 
-    "deepseek-vl2": 4,
-    "deepseek-ai/deepseek-vl2": 4,
+    "qwen3-coder-plus": 4,
+    "qwen3-coder-plus-2025-07-22": 4,
 
     # 豆包
+    "seed-x-ppo-7b": 1,
+
+    "doubao-seed-1-6-flash-250715": 10,
     "doubao-seed-1-6-flash-250615": 10,
     # doubao-seed-1-6-flash-250615,doubao-seed-1-6-250615,doubao-seed-1-6-thinking-250615
     "doubao-seed-1-6-250615": 10,
     "doubao-seed-1-6-thinking-250615": 10,
+    "doubao-seed-1-6-thinking-250715": 10,
 
     "doubao-1-5-ui-tars-250428": 3.43,
     "ui-tars-72b": 4,
@@ -1451,6 +1544,12 @@ COMPLETION_RATIO = {
     "glm-4.1v-thinking-flash": 2,
     "glm-4.1v-thinking-flashx": 4,
 
+    "glm-4.5-flash": 3,
+    "glm-4.5-air": 3,
+    "glm-4.5-airx": 3,
+    "glm-4.5": 4,
+    "glm-4.5-x": 4,
+
     "step-1-flash": 5,
     "step-1-8k": 5,
     "step-1-32k": 5,
@@ -1667,9 +1766,10 @@ if __name__ == '__main__':
 
     print([k for k in MODEL_RATIO if k.startswith(('deepseek', 'doubao', 'moon'))] | xjoin(","))
 
+    print('\n\n')
+    print([k for k in MODEL_RATIO if k.startswith(('glm-4.'))] | xjoin(","))
+
     print([k for k in MODEL_PRICE if k.startswith(('chat-',))] | xjoin(","))
 
-
-
-
-    print(','.join(FAL_MODELS)) #  fal 按次
+    print("FAL按次")
+    print(','.join(FAL_MODELS))  # fal 按次
